@@ -5,8 +5,6 @@ require File.expand_path File.join(File.dirname(__FILE__), 'extract_tab_list')
 
 Plugin.create :extract do
 
-  DEFINED_TIME = Time.new.freeze
-
   # 抽出タブオブジェクト。各キーは抽出タブIDで、値は以下のようなオブジェクト
   # name :: タブの名前
   # sexp :: 条件式（S式）
@@ -184,19 +182,20 @@ Plugin.create :extract do
     converted_messages = Messages.new(messages.map{ |message| message.retweet_source ? message.retweet_source : message })
     tabs.deach{ |record|
       begin
-        filtered_messages = converted_messages.select(&compile(record[:id], record[:sexp])).freeze
+        filtered_messages = timeline(record[:slug]).not_in_message(converted_messages.select(&compile(record[:id], record[:sexp]))).freeze
         unless filtered_messages.empty?
           timeline(record[:slug]) << filtered_messages
-          notificate_messages = lazy{ filtered_messages.select{|message| message[:created] > DEFINED_TIME} }
+          notificate_messages = filtered_messages.lazy.select{|message| message[:created] > defined_time}
           if record[:popup]
             notificate_messages.each do |message|
               notice message.user.idname + " " + message.to_show
               Plugin.call(:popup_notify, message.user, message.to_show) end end
-          if record[:sound].is_a?(String) and not notificate_messages.empty? and FileTest.exist?(record[:sound])
+          if record[:sound].is_a?(String) and notificate_messages.first and FileTest.exist?(record[:sound])
             Plugin.call(:play_sound, record[:sound]) end
         end
-      rescue Exception => e
-        error "filter '#{record[:name]}' crash: #{e.to_s}" end } end
+      rescue Exception => exception
+        error "filter '#{record[:name]}' crash: #{exception.to_s}"
+        error exception end } end
 
   (UserConfig[:extract_tabs] or []).each{ |record|
     extract_tabs[record[:id]] = record.freeze
