@@ -289,7 +289,7 @@ Plugin.create :gtk do
 
       menu.append(Gtk::SeparatorMenuItem.new) if items.length != 0
       menu2 = Gtk::ContextMenu.new(*items).build!(i_postbox, event, menu)
-      menu2.show_all 
+      menu2.show_all
 
       true }
 
@@ -345,6 +345,10 @@ Plugin.create :gtk do
   on_gui_timeline_set_order do |i_timeline, order|
     widgetof(i_timeline).set_order(&order) end
 
+  filter_gui_timeline_has_messages do |i_timeline, messages|
+    [i_timeline,
+     messages.select(&widgetof(i_timeline).method(:include?))] end
+
   on_gui_postbox_post do |i_postbox|
     postbox = widgetof(i_postbox)
     if postbox
@@ -435,7 +439,7 @@ Plugin.create :gtk do
           mp.on_modify } end } end
 
   on_favorite do |service, user, message|
-    if(user.is_me?)
+    if(user.me?)
       Gdk::MiraclePainter.findbymessage(message).each{ |mp|
         mp.on_modify } end end
 
